==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CalloutContentUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalloutContentUpdatingEventArgsDescription } from "./CalloutContentUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let CalloutContentUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutContentUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutContentUpdatingEventArgsDescriptionMetadata.a == null) {
                CalloutContentUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutContentUpdatingEventArgsDescriptionMetadata.c(CalloutContentUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(CalloutContentUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(CalloutContentUpdatingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
            a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
            a.item("ContentRef", "(w:Content,j:content,wf:Content)DataRef");
        }
        static d(a) {
            CalloutContentUpdatingEventArgsDescriptionMetadata.b(a);
            a.ac("CalloutContentUpdatingEventArgs", () => new CalloutContentUpdatingEventArgsDescription());
            a.ab("CalloutContentUpdatingEventArgs", CalloutContentUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    CalloutContentUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CalloutContentUpdatingEventArgsDescriptionMetadata, 'CalloutContentUpdatingEventArgsDescriptionMetadata');
    CalloutContentUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutContentUpdatingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/CalloutContentUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalloutContentUpdatingEventArgsDescription } from "./CalloutContentUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let CalloutContentUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutContentUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutContentUpdatingEventArgsDescriptionMetadata.a == null) {
                CalloutContentUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutContentUpdatingEventArgsDescriptionMetadata.c(CalloutContentUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(CalloutContentUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(CalloutContentUpdatingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
            a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
            a.item("ContentRef", "(w:Content,j:content,wf:Content)DataRef");
        }
        static d(a) {
            CalloutContentUpdatingEventArgsDescriptionMetadata.b(a);
            a.ae("CalloutContentUpdatingEventArgs", () => new CalloutContentUpdatingEventArgsDescription());
            a.ad("CalloutContentUpdatingEventArgs", CalloutContentUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    CalloutContentUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CalloutContentUpdatingEventArgsDescriptionMetadata, 'CalloutContentUpdatingEventArgsDescriptionMetadata');
    CalloutContentUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutContentUpdatingEventArgsDescriptionMetadata;
})();
